@@ -1,4 +1,4 @@
-# Copyright (c) 2011, SD Elements. See LICENSE file for details.
+# Copyright (c) 2011, SD Elements. See LICENSE.txt for details.
 
 from datetime import datetime, MINYEAR, MAXYEAR
 
@@ -29,3 +29,6 @@ class PasswordExpiry(models.Model):
         self.password_expiry_date = datetime(MAXYEAR, 12, 31)
         self.save()
 
+    class Meta:
+        verbose_name_plural = "PasswordExpiries"
+
